@@ -1,5 +1,5 @@
 package AI::ConfusionMatrix;
-$AI::ConfusionMatrix::VERSION = '0.004';
+$AI::ConfusionMatrix::VERSION = '0.005';
 use Carp;
 use Exporter 'import';
 our @EXPORT= qw (makeConfusionMatrix);
@@ -60,7 +60,7 @@ sub makeConfusionMatrix {
             # Calculate the index of the label in the array of columns
             $index = _findIndex($predicted, \@columns);
             # Print some commas to get to the column of the next value predicted
-            $array[$n] .= ',' x ($index - $lastIndex) . %{$matrix}{$expected}->{$predicted};
+            $array[$n] .= ',' x ($index - $lastIndex) . $matrix->{$expected}{$predicted};
             $lastIndex = $index;
         }
 
